@import url(http://fonts.googleapis.com/css?family=PT+Serif);
@import url(http://fonts.googleapis.com/css?family=PT+Sans);
/* HTML5 ✰ Boilerplate */

html, body, div, span, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
abbr, address, cite, code, del, dfn, em, img, ins, kbd, q, samp,
small, strong, sub, sup, var, b, i, dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, figcaption, figure,
footer, header, hgroup, menu, nav, section, summary,
time, mark, audio, video {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
}

article, aside, details, figcaption, figure,
footer, header, hgroup, menu, nav, section {
  display: block;
}

blockquote, q { quotes: none; }
blockquote:before, blockquote:after,
q:before, q:after { content: ""; content: none; }
ins { background-color: #ff9; color: #000; text-decoration: none; }
mark { background-color: #ff9; color: #000; font-style: italic; font-weight: bold; }
del { text-decoration: line-through; }
abbr[title], dfn[title] { border-bottom: 1px dotted; cursor: help; }
table { border-collapse: collapse; border-spacing: 0; }
hr { display: block; height: 1px; border: 0; border-top: 1px solid #ccc; margin: 1em 0; padding: 0; }
input, select { vertical-align: middle; }

body { font:13px/1.231 sans-serif; *font-size:small; }
select, input, textarea, button { font:99% sans-serif; }
pre, code, kbd, samp { font-family: monospace, sans-serif; }

html { overflow-y: scroll; }
a:hover, a:active { outline: none; }
ul, ol { margin-left: 2em; }
ol { list-style-type: decimal; }
nav ul, nav li { margin: 0; list-style:none; list-style-image: none; }
small { font-size: 85%; }
strong, th { font-weight: bold; }
td { vertical-align: top; }
sub, sup { font-size: 75%; line-height: 0; position: relative; }
sup { top: -0.5em; }
sub { bottom: -0.25em; }

pre { white-space: pre; white-space: pre-wrap; word-wrap: break-word; padding: 15px; }
textarea { overflow: auto; } 
.ie6 legend, .ie7 legend { margin-left: -7px; } 
input[type="radio"] { vertical-align: text-bottom; }
input[type="checkbox"] { vertical-align: bottom; }
.ie7 input[type="checkbox"] { vertical-align: baseline; }
.ie6 input { vertical-align: text-bottom; }
label, input[type="button"], input[type="submit"], input[type="image"], button { cursor: pointer; }
button, input, select, textarea { margin: 0; }
input:valid, textarea:valid   {  }
input:invalid, textarea:invalid { border-radius: 1px; -moz-box-shadow: 0px 0px 5px red; -webkit-box-shadow: 0px 0px 5px red; box-shadow: 0px 0px 5px red; }
.no-boxshadow input:invalid, .no-boxshadow textarea:invalid { background-color: #f0dddd; }


::-moz-selection{ background: #FF5E99; color:#fff; text-shadow: none; }
::selection { background:#FF5E99; color:#fff; text-shadow: none; }
a:link { -webkit-tap-highlight-color: #FF5E99; }
button {  width: auto; overflow: visible; }
.ie7 img { -ms-interpolation-mode: bicubic; }

body, select, input, textarea { color: #444; }
h1, h2, h3, h4, h5, h6 { font-weight: bold; }


body{
    background-color:#ededed;
    width:100%;
    margin:50px auto;
    font-family: 'PT Sans', arial, serif;
    color:#0c0c0c;
    line-height:1.5;
    text-shadow:1px 0 1px #fff;
}

a, a:visited, a:hover, a:focus{
    color:#0c0c0c;
    text-decoration:none;
}

a:hover{
    text-decoration:underline;;
}

h1{
    font-family: 'PT Serif', arial, serif;
    font-weight:bold;
    font-size:26px;
    margin-bottom:40px;
    margin-top:0;
}

h2{
    font-size:18px;
    font-style:italic;
    font-weight:normal;
    margin-bottom:20px;
}

#container{
    margin:170px auto;
    width:auto;
}

#dashboard ul{
    list-style-type:none;
    text-align:center;
}

#dashboard ul li{
    background:url('../img/dashboard-bg.png');
    width:233px;
    display:inline-block;
    margin:20px;
    padding:40px 0;
    border:1px solid #ccc;
    border-radius:5px;
    text-align:center;
}

#dashboard ul li h1{
    margin-bottom:0;
}

a.warning{
    color:#ff0000;
}

#graphcontainer{
    margin:0 auto;
    width:700px;
    text-align:center;
}

.graph{
    margin:0 auto;
    width:700px;
    height:300px;
    margin-bottom:40px;
}

