<!doctype html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

	<title>Dashboard</title>
	<link rel="stylesheet" href="{{ STATIC_URL }}css/dashboard.css">
	{% block extrajs %}{% endblock %}
</head>

<body>
	<div id="container">
		
		<div id="dashboard" class="clearfix">
		{% block content %}
			<ul>
				{% for m in bb %}
				<li>
					<div class="head">
						<h2>{{ m.name }}</h2>
					</div>
					<div class="num">
						<h1>
							<a href="{% url bigbrother.views.graph slug=m.name|slugify %}" 
							{% if m.warning %}class="warning"{% endif %}>{{ m.text }}
							</a>
						</h1>
					</div>
				</li>
				{% endfor %}
			</ul>
		{% endblock %}
		</div>
		
	</div>
</body>
</html>